#property script_show_inputs

input datetime inFrom = D'2021.06.01';
input int inTimeDepth = 1000;   //  ()  -
input bool inMT5Detail = false; //   MT5-
input ulong inOrderTicket = 0;  //  MT5-  

#include <MT4Orders.mqh> // https://www.mql5.com/ru/code/16006

#define TIME   0
#define TICKET 1

int GetOrders( ulong &Orders[][2] )
{
  int Amount = 0;

  const int Total = HistoryOrdersTotal();

  ArrayResize(Orders,  Total << 1);

  for (int i = 0; i < Total; i++)
  {
    const ulong Ticket = HistoryOrderGetTicket(i);

    if ((HistoryOrderGetInteger(Ticket, ORDER_REASON) == ORDER_REASON_EXPERT) &&
        (HistoryOrderGetInteger(Ticket, ORDER_TYPE) != ORDER_TYPE_CLOSE_BY) &&
        HistoryOrderGetInteger(Ticket, ORDER_MAGIC))
    {
      Orders[Amount][TIME] = HistoryOrderGetInteger(Ticket, ORDER_TIME_SETUP_MSC);
      Orders[Amount++][TICKET] = Ticket;

      if ((HistoryOrderGetInteger(Ticket, ORDER_STATE) == ORDER_STATE_FILLED) &&
          (HistoryOrderGetInteger(Ticket, ORDER_POSITION_ID) == Ticket))
      {
        Orders[Amount][TIME] = HistoryOrderGetInteger(Ticket, ORDER_TIME_DONE_MSC);
        Orders[Amount++][TICKET] = Ticket;
      }
    }
  }

  return(ArrayResize(Orders, Amount));
}

int CheckOrder( const ulong &Orders[][2], const int Pos, const int TimeDepth = 1000 )
{
  const ulong Ticket = Orders[Pos][TICKET];
  const int Type = (int)HistoryOrderGetInteger(Ticket, ORDER_TYPE) & 1;
  const ulong Magic = HistoryOrderGetInteger(Ticket, ORDER_MAGIC);
  const string Symb = HistoryOrderGetString(Ticket, ORDER_SYMBOL);


  const ulong Time = Orders[Pos][TIME] + TimeDepth;

  const int Size = ArrayRange(Orders, 0);
  int i = Pos + 1;

  for (; i < Size; i++)
    if (Orders[i][TIME] > Time)
    {
      i = Pos;

      break;
    }
    else
    {
      const ulong Ticket2 = Orders[i][TICKET];
      const int Type2 = (int)HistoryOrderGetInteger(Ticket2, ORDER_TYPE) & 1;
      const ulong Magic2 = HistoryOrderGetInteger(Ticket2, ORDER_MAGIC);
      const string Symb2 = HistoryOrderGetString(Ticket2, ORDER_SYMBOL);

      if ((Ticket != Ticket2) && (Type == Type2) && (Magic == Magic2) && (Symb == Symb2) &&
          ((HistoryOrderGetInteger(Ticket, ORDER_STATE) != ORDER_STATE_REJECTED) ||
           (HistoryOrderGetInteger(Ticket, ORDER_TIME_DONE_MSC) > HistoryOrderGetInteger(Ticket2, ORDER_TIME_SETUP_MSC))) &&
          // MT4Orders:
          OrderSelect(Ticket, SELECT_BY_TICKET) &&
          ((OrderType() > OP_SELL) || (OrderCloseTimeMsc() >= HistoryOrderGetInteger(Ticket2, ORDER_TIME_SETUP_MSC))) &&
          OrderSelect(Ticket2, SELECT_BY_TICKET) &&
          ((OrderType() > OP_SELL) || (OrderCloseTimeMsc() >= HistoryOrderGetInteger(Ticket, ORDER_TIME_SETUP_MSC))))
        break;
    }

  if (i == Size)
    i = Pos;

  return(i);
}

void OnStart()
{
  if (HistorySelect(inFrom, INT_MAX))
  {
    ulong Orders[][2];

    const int Size = GetOrders(Orders) - 1;

    ArraySort(Orders);

    for (int i = 0; !IsStopped() && (i < Size); i++)
    {
      const int Pos = CheckOrder(Orders, i, inTimeDepth);

      if ((Pos != i) && (!inOrderTicket || (Orders[i][TICKET] == inOrderTicket) || (Orders[Pos][TICKET] == inOrderTicket)))
        PrintOrders(Orders[i][TICKET], Orders[Pos][TICKET]);
    }
  }
}

#undef TICKET
#undef TIME

string TimeToString( const long Time )
{
  return((string)(datetime)(Time / 1000) + "." + IntegerToString(Time % 1000, 3, '0'));
}

string MT5OrderToString( const ulong Ticket )
{
  return("Ticket = " + (string)Ticket +
         ", Magic = " + (string)HistoryOrderGetInteger(OrderTicketID(), ORDER_MAGIC) +
         ", Type = " + EnumToString((ENUM_ORDER_TYPE)HistoryOrderGetInteger(Ticket, ORDER_TYPE)) +
         ", State = " + EnumToString((ENUM_ORDER_STATE)HistoryOrderGetInteger(Ticket, ORDER_STATE)) +
         ", Reason = " + EnumToString((ENUM_ORDER_REASON)HistoryOrderGetInteger(Ticket, ORDER_REASON)) +
         ", " + TimeToString(HistoryOrderGetInteger(Ticket, ORDER_TIME_SETUP_MSC)) + " - " + TimeToString(HistoryOrderGetInteger(Ticket, ORDER_TIME_DONE_MSC)) +
         ", Lots = " + DoubleToString(HistoryOrderGetDouble(Ticket, ORDER_VOLUME_CURRENT), 2) +
         "/" + DoubleToString(HistoryOrderGetDouble(Ticket, ORDER_VOLUME_INITIAL), 2));
}

void PrintOrder( const ulong Ticket, const bool Detail = false )
{
  if (OrderSelect(Ticket, SELECT_BY_TICKET))
  {
    OrderPrint();

    if (Detail)
    {
      if (OrderType() <= OP_SELL)
      {
        Print("Open" + MT5OrderToString(OrderTicketID()));
        Print("Close" + MT5OrderToString(HistoryDealGetInteger(OrderTicket(), DEAL_ORDER)));

        if (OrderOpenTimeMsc() < HistoryOrderGetInteger(OrderTicketID(), ORDER_TIME_SETUP_MSC))
          Print("Bug: https://www.mql5.com/ru/forum/170952/page207#comment_23996603");
      }
      else
        Print(MT5OrderToString(Ticket));
    }
  }
}

void PrintOrders( const ulong Ticket1, const ulong Ticket2 )
{
  Print("\n" + (string)Ticket1 + " - " + (string)Ticket2);

  const bool Detail = inMT5Detail || (Ticket1 == inOrderTicket) || (Ticket2 == inOrderTicket);

  PrintOrder(Ticket1, Detail);
  PrintOrder(Ticket2, Detail);
}